==> jboss-as-system-5.0.0.GA-sources.jar: org/jboss/system/server/profileservice/repository/SerializableDeploymentRepositoryFactory.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2006, Red Hat Middleware LLC, and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.system.server.profileservice.repository;

import java.io.File;
import java.net.URI;
import java.util.HashMap;

import org.jboss.deployers.structure.spi.main.MainDeployerStructure;
import org.jboss.profileservice.spi.AttachmentsSerializer;
import org.jboss.profileservice.spi.DeploymentRepository;
import org.jboss.profileservice.spi.DeploymentRepositoryFactory;
import org.jboss.profileservice.spi.ProfileKey;
import org.jboss.virtual.VirtualFileFilter;

/**
 * Factory for SerializableDeploymentRepository
 * 
 * @author Scott.Stark@jboss.org
 * @version $Revision:$
 */
public class SerializableDeploymentRepositoryFactory
   implements DeploymentRepositoryFactory
{
   /** The server root containing the deployments */
   private File root;
   /** The root location for admin edits */
   private String attachmentsRoot;
   /** The URIs for the application deployments */
   private URI[] appURIs = {};
   /** The attachment serializer */
   private AttachmentsSerializer serializer;
   /** The main deployer structure */
   private MainDeployerStructure mainDeployer;
   /** The deployment filter */
   private VirtualFileFilter deploymentFilter;
   /** The HotDeployment filter */
   private VirtualFileFilter hotDeploymentFilter;
   
   /** The profile repositories */
   private HashMap<ProfileKey, DeploymentRepository> profileRepositories
      = new HashMap<ProfileKey, DeploymentRepository>();
   
   /**
    * Get the server profile store root directory.
    * @return the server profile root directory containing the
    * available profiles.
    */
   public File getStoreRoot()
   {
      return root;
   }
   /**
    * Set the profiles store root.
    * @param root - the server profile root directory containing the
    * available profiles.
    */
   public void setStoreRoot(File root)
   {
      this.root = root;
   }
   public String getAttachmentsRoot()
   {
      return attachmentsRoot;
   }
   public void setAttachmentsRoot(String attachmentsRoot)
   {
      this.attachmentsRoot = attachmentsRoot;
   }
   public URI[] getApplicationURIs()
   {
      return appURIs;
   }
   public void setApplicationURIs(URI[] appURIs)
   {
      this.appURIs = appURIs;
   }

   public AttachmentsSerializer getSerializer()
   {
      return serializer;
   }

   public void setSerializer(AttachmentsSerializer serializer)
   {
      this.serializer = serializer;
   }
   
   public VirtualFileFilter getDeploymentFilter()
   {
      return deploymentFilter;
   }
   
   public void setDeploymentFilter(VirtualFileFilter deploymentFilter)
   {
      this.deploymentFilter = deploymentFilter;
   }
   
   public VirtualFileFilter getHotDeploymentFilter()
   {
      return hotDeploymentFilter;
   }
   
   public void setHotDeploymentFilter(VirtualFileFilter hotDeploymentFilter)
   {
      this.hotDeploymentFilter = hotDeploymentFilter;
   }
   
   public MainDeployerStructure getMainDeployer()
   {
      return mainDeployer;
   }
   
   public void setMainDeployer(MainDeployerStructure mainDeployer)
   {
      this.mainDeployer = mainDeployer;
   }

   public synchronized DeploymentRepository getDeploymentRepository(ProfileKey key)
   {
      if (appURIs == null || appURIs.length == 0)
      {
         File deployDir = new File(root, key.getName()+"/deploy");
         appURIs = new URI[]{deployDir.toURI()};
      }
      DeploymentRepository dr = profileRepositories.get(key);
      if(dr == null)
      {
         SerializableDeploymentRepository repo = new SerializableDeploymentRepository(root, appURIs, key);
         repo.setAttachmentsRoot(attachmentsRoot);
         repo.setSerializer(serializer);
         repo.setDeploymentFilter(deploymentFilter);
         repo.setHotDeploymentFilter(hotDeploymentFilter);
         repo.setMainDeployer(mainDeployer);
         profileRepositories.put(key, repo);
         dr = repo;
      }
      return dr;
   }
}

==> jboss-as-system-5.0.1.GA-sources.jar: org/jboss/system/server/profileservice/repository/SerializableDeploymentRepositoryFactory.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2006, Red Hat Middleware LLC, and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.system.server.profileservice.repository;

import java.io.File;
import java.net.URI;
import java.util.HashMap;
import java.util.Map;

import org.jboss.deployers.structure.spi.main.MainDeployerStructure;
import org.jboss.deployers.vfs.spi.structure.modified.StructureModificationChecker;
import org.jboss.profileservice.spi.AttachmentsSerializer;
import org.jboss.profileservice.spi.DeploymentRepository;
import org.jboss.profileservice.spi.DeploymentRepositoryFactory;
import org.jboss.profileservice.spi.ProfileKey;
import org.jboss.virtual.VirtualFileFilter;

/**
 * Factory for SerializableDeploymentRepository
 * 
 * @author Scott.Stark@jboss.org
 * @version $Revision:$
 */
public class SerializableDeploymentRepositoryFactory
   implements DeploymentRepositoryFactory
{
   /** The server root containing the deployments */
   private File root;
   /** The root location for admin edits */
   private String attachmentsRoot;
   /** The URIs for the application deployments */
   private URI[] appURIs = {};
   /** The attachment serializer */
   private AttachmentsSerializer serializer;
   /** The main deployer structure */
   private MainDeployerStructure mainDeployer;
   /** The deployment filter */
   private VirtualFileFilter deploymentFilter;
   /** The HotDeployment filter */
   private VirtualFileFilter hotDeploymentFilter;
   /** The structure modification checker */
   private StructureModificationChecker checker;

   /** The profile repositories */
   private Map<ProfileKey, DeploymentRepository> profileRepositories = new HashMap<ProfileKey, DeploymentRepository>();
   
   /**
    * Get the server profile store root directory.
    * @return the server profile root directory containing the
    * available profiles.
    */
   public File getStoreRoot()
   {
      return root;
   }
   /**
    * Set the profiles store root.
    * @param root - the server profile root directory containing the
    * available profiles.
    */
   public void setStoreRoot(File root)
   {
      this.root = root;
   }
   public String getAttachmentsRoot()
   {
      return attachmentsRoot;
   }
   public void setAttachmentsRoot(String attachmentsRoot)
   {
      this.attachmentsRoot = attachmentsRoot;
   }
   public URI[] getApplicationURIs()
   {
      return appURIs;
   }
   public void setApplicationURIs(URI[] appURIs)
   {
      this.appURIs = appURIs;
   }

   public AttachmentsSerializer getSerializer()
   {
      return serializer;
   }

   public void setSerializer(AttachmentsSerializer serializer)
   {
      this.serializer = serializer;
   }
   
   public VirtualFileFilter getDeploymentFilter()
   {
      return deploymentFilter;
   }
   
   public void setDeploymentFilter(VirtualFileFilter deploymentFilter)
   {
      this.deploymentFilter = deploymentFilter;
   }

   @Deprecated
   public VirtualFileFilter getHotDeploymentFilter()
   {
      return hotDeploymentFilter;
   }

   @Deprecated
   public void setHotDeploymentFilter(VirtualFileFilter hotDeploymentFilter)
   {
      this.hotDeploymentFilter = hotDeploymentFilter;
   }

   public MainDeployerStructure getMainDeployer()
   {
      return mainDeployer;
   }

   public void setMainDeployer(MainDeployerStructure mainDeployer)
   {
      this.mainDeployer = mainDeployer;
   }

   public StructureModificationChecker getChecker()
   {
      return checker;
   }

   public void setChecker(StructureModificationChecker checker)
   {
      this.checker = checker;
   }

   public synchronized DeploymentRepository getDeploymentRepository(ProfileKey key)
   {
      if (appURIs == null || appURIs.length == 0)
      {
         File deployDir = new File(root, key.getName()+"/deploy");
         appURIs = new URI[]{deployDir.toURI()};
      }
      DeploymentRepository dr = profileRepositories.get(key);
      if(dr == null)
      {
         SerializableDeploymentRepository repo = new SerializableDeploymentRepository(root, appURIs, key);
         repo.setAttachmentsRoot(attachmentsRoot);
         repo.setSerializer(serializer);
         repo.setDeploymentFilter(deploymentFilter);
         repo.setHotDeploymentFilter(hotDeploymentFilter);
         repo.setMainDeployer(mainDeployer);
         repo.setChecker(checker);
         profileRepositories.put(key, repo);
         dr = repo;
      }
      return dr;
   }
}
